==> nrobo-2024.5.1-py3-none-any.whl: nrobo/util/commands/ncommands/__init__.py <==
"""
=====================CAUTION=======================
DO NOT DELETE THIS FILE SINCE IT IS PART OF NROBO
FRAMEWORK AND IT MAY CHANGE IN THE FUTURE UPGRADES
OF NROBO FRAMEWORK. THUS, TO BE ABLE TO SAFELY UPGRADE
TO LATEST NROBO VERSION, PLEASE DO NOT DELETE THIS
FILE OR ALTER ITS LOCATION OR ALTER ITS CONTENT!!!
===================================================

@author: Panchdev Singh Chauhan
@email: erpanchdev@gmail.com
"""

import os

from nrobo import *
from nrobo.exceptions import *
from nrobo.util.commands.posix import POSIX_COMMAND
from nrobo.util.commands.windows import WINDOWS_COMMAND
from nrobo.util.platform import PLATFORMS
from nrobo.util.process import terminal


class N_COMMANDS:
    """
    This class hold nrobo command mappings for host platform.

    Raises <MissingCommandImplementation> exception
    If there is no implementation for host platform.
    """
    CLEAR_SCREEN = "clear screen"
    COMMAND = {
        PLATFORMS.WINDOWS: {
            CLEAR_SCREEN: WINDOWS_COMMAND.CLS,
        },
        PLATFORMS.DARWIN: {
            CLEAR_SCREEN: POSIX_COMMAND.CLEAR
        }
    }


def get_command(command):
    """
    Return the appropriate posix or windows <command> to caller.

    :param command:
    :return:
    """
    try:
        return N_COMMANDS.COMMAND[os.environ[EnvKeys.HOST_PLATFORM]][N_COMMANDS.CLEAR_SCREEN]
    except KeyError as ke:
        raise MissingCommandImplementation(N_COMMANDS.CLEAR_SCREEN)


def clear_screen():
    """
    Run the clear screen command.

    :return:
    """
    terminal([get_command(N_COMMANDS.CLEAR_SCREEN)])


def remove_files_recursively(directory):
    """
    Remove <directory>

    :param directory:
    :return:
    """
    run_status = terminal(["rm", "-rf", directory])
    return run_status

==> nrobo-2024.21.2-py3-none-any.whl: nrobo/util/commands/ncommands/__init__.py <==
"""
=====================CAUTION=======================
DO NOT DELETE THIS FILE SINCE IT IS PART OF NROBO
FRAMEWORK AND IT MAY CHANGE IN THE FUTURE UPGRADES
OF NROBO FRAMEWORK. THUS, TO BE ABLE TO SAFELY UPGRADE
TO LATEST NROBO VERSION, PLEASE DO NOT DELETE THIS
FILE OR ALTER ITS LOCATION OR ALTER ITS CONTENT!!!
===================================================

@author: Panchdev Singh Chauhan
@email: erpanchdev@gmail.com
"""

import os

from nrobo import *
from nrobo.exceptions import *
from nrobo.util.commands.posix import POSIX_COMMAND
from nrobo.util.commands.windows import WINDOWS_COMMAND
from nrobo.util.platform import PLATFORMS
from nrobo.util.process import terminal, terminal_nogui


class N_COMMANDS:
    """N_COMMANDS class hold nrobo command mappings for host platform.

    Raises <MissingCommandImplementation> exception
    If there is no implementation for host platform."""

    CLEAR_SCREEN = "clear screen"
    COMMAND = {
        PLATFORMS.WINDOWS: {
            CLEAR_SCREEN: WINDOWS_COMMAND.CLS,
        },
        PLATFORMS.DARWIN: {
            CLEAR_SCREEN: POSIX_COMMAND.CLEAR
        }
    }


def get_command(command) -> None:
    """Return the appropriate posix or windows <command> to caller."""

    try:
        return N_COMMANDS.COMMAND[os.environ[EnvKeys.HOST_PLATFORM]][N_COMMANDS.CLEAR_SCREEN]
    except KeyError as ke:
        raise MissingCommandImplementation(N_COMMANDS.CLEAR_SCREEN)


def clear_screen():
    """Run the clear screen command."""
    terminal([get_command(N_COMMANDS.CLEAR_SCREEN)])


def remove_files_recursively(directory):
    """Remove <directory>

    :param directory:
    :return:"""

    run_status = terminal(["rm", "-rf", directory])
    return run_status
